"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = require("lodash");
const path_1 = require("path");
const ui_aspect_1 = require("./ui.aspect");
function createRoot(aspectDefs, rootExtensionName, rootAspect = ui_aspect_1.UIAspect.id, runtime = 'ui') {
    return __awaiter(this, void 0, void 0, function* () {
        const rootId = rootExtensionName ? `'${rootExtensionName}'` : '';
        const defs = aspectDefs.filter((def) => def.runtimePath);
        return `
import { Harmony } from '@teambit/harmony';
${getImportStatements(aspectDefs.map((def) => def.aspectPath), 'Aspect')}
${getImportStatements(defs.map((def) => def.runtimePath), 'Runtime')}

Harmony.load([${getIdentifiers(aspectDefs.map((def) => def.aspectPath), 'Aspect')}], '${runtime}', {})
  .then((harmony) => {
    harmony
      .run()
      .then(() => {
        const rootExtension = harmony.get('${rootAspect}');
        rootExtension.render(${rootId});
      })
      .catch((err) => {
        throw err;
      });
  });
  `;
    });
}
exports.createRoot = createRoot;
function getImportStatements(extensionPaths, suffix) {
    return extensionPaths.map((path) => `import ${getIdentifier(path, suffix)} from '${path}';`).join('\n');
}
function getIdentifiers(extensionsPaths, suffix) {
    return extensionsPaths.map((path) => `${getIdentifier(path, suffix)}`).join(', ');
}
function getIdentifier(path, suffix) {
    return lodash_1.camelCase(`${path_1.parse(path).name.split('.')[0]}${suffix}`);
}
//# sourceMappingURL=create-root.js.map